==> haskell-uri-bytestring-0.3.2.1-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.3.2.1
id: uri-bytestring-0.3.2.1-5QxcftOMQZT78MC4GbZ3yb
key: uri-bytestring-0.3.2.1-5QxcftOMQZT78MC4GbZ3yb
license: BSD-3-Clause
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
author: Doug Beardsley, Michael Xavier
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
abi: dc52f7e42d96c189c96f8e83c6ef04ff
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/uri-bytestring-0.3.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/uri-bytestring-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/uri-bytestring-0.3.2.1
hs-libraries: HSuri-bytestring-0.3.2.1-5QxcftOMQZT78MC4GbZ3yb
depends:
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 template-haskell-2.14.0.0
    th-lift-instances-0.1.11-KEK8nmCaHnrC13tbi99jb2
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.3.2.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.3.2.1
id: uri-bytestring-0.3.2.1-3RtxVu35kbxDgr7XJZVsNM
key: uri-bytestring-0.3.2.1-3RtxVu35kbxDgr7XJZVsNM
license: BSD-3-Clause
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
author: Doug Beardsley, Michael Xavier
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
abi: 57796548902fecd3ff02a8e856f398ac
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/uri-bytestring-0.3.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/uri-bytestring-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/uri-bytestring-0.3.2.1
hs-libraries: HSuri-bytestring-0.3.2.1-3RtxVu35kbxDgr7XJZVsNM
depends:
    attoparsec-0.13.2.3-G0AWAouFPeyAsmzjnpc0yX base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    containers-0.6.0.1 template-haskell-2.14.0.0
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
